@@ -11,12 +11,19 @@ class AlternativeRiskFactor(RiskFactor):
 
 class AlternativeRiskFactors(GbdRecord):
     """Holder of alternative risk factors."""
-    __slots__ = ('child_wasting', 'child_underweight', 'child_stunting', )
 
-    def __init__(self,
-                 child_stunting: AlternativeRiskFactor,
-                 child_underweight: AlternativeRiskFactor,
-                 child_wasting: AlternativeRiskFactor,):
+    __slots__ = (
+        "child_wasting",
+        "child_underweight",
+        "child_stunting",
+    )
+
+    def __init__(
+        self,
+        child_stunting: AlternativeRiskFactor,
+        child_underweight: AlternativeRiskFactor,
+        child_wasting: AlternativeRiskFactor,
+    ):
         self.child_stunting = child_stunting
         self.child_underweight = child_underweight
         self.child_wasting = child_wasting
